import { MantineProvider } from '@mantine/core';
import { BrowserRouter, Routes, Route } from 'react-router-dom';
import { theme } from './theme';
import { LandingPage } from './pages/LandingPage';
import { DocsLayout } from './layouts/DocsLayout';
import { GettingStarted } from './pages/docs/GettingStarted';
import { Installation } from './pages/docs/Installation';
import { BasicUsage } from './pages/docs/BasicUsage';
import { Configuration } from './pages/docs/Configuration';
import { ErrorHandling } from './pages/docs/ErrorHandling';
import { TypeInference } from './pages/docs/TypeInference';
import { Caching } from './pages/docs/Caching';
import { Interceptors } from './pages/docs/Interceptors';
import { APIReference } from './pages/docs/APIReference';
import '@mantine/core/styles.css';
import '@mantine/prism/styles.css';
import '@mantine/spotlight/styles.css';
import './styles/global.css';

export function App() {
  return (
    <MantineProvider theme={theme} defaultColorScheme="dark">
      <BrowserRouter>
        <Routes>
          <Route path="/" element={<LandingPage />} />
          <Route path="/docs" element={<DocsLayout />}>
            <Route index element={<GettingStarted />} />
            <Route path="installation" element={<Installation />} />
            <Route path="basic-usage" element={<BasicUsage />} />
            <Route path="configuration" element={<Configuration />} />
            <Route path="error-handling" element={<ErrorHandling />} />
            <Route path="type-inference" element={<TypeInference />} />
            <Route path="caching" element={<Caching />} />
            <Route path="interceptors" element={<Interceptors />} />
            <Route path="api-reference" element={<APIReference />} />
          </Route>
        </Routes>
      </BrowserRouter>
    </MantineProvider>
  );
}